=========
Wrangling
=========

This module contains :class:`StructureWrangler`, which handles input
data structures and properties to fit to the cluster expansion.
:code:`wrangling` also provides some tools for preprocessing and
calculating weights (e.g. by energy above hull or energy above
composition) for the structures in :code:`tools.py` and filtering
by structure/property/energy data in :code:`select.py`.

.. toctree::
   :maxdepth: 2

   wrangling.sw
   wrangling.tools
   wrangling.select
